.. _spkg_pyparsing:

pyparsing: A Python parsing module
==================================

Description
-----------

A Python Parsing Module

License
-------

MIT License


Upstream Contact
----------------

https://pypi.org/project/pyparsing/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    3.2.5

version_requirements.txt::

    pyparsing >=3.2.3

See https://repology.org/project/pyparsing/versions, https://repology.org/project/python:pyparsing/versions

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install pyparsing\>=3.2.3

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i pyparsing

.. tab:: Arch Linux:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S python-pyparsing

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install pyparsing

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install python3-pyparsing

.. tab:: FreeBSD:

   .. CODE-BLOCK:: bash

       $ sudo pkg install devel/py-pyparsing

.. tab:: Gentoo Linux:

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-python/pyparsing

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-python-pyparsing

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install python3-pyparsing

.. tab:: Void Linux:

   .. CODE-BLOCK:: bash

       $ sudo xbps-install python3-parsing


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
